"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SdGenerationStyle(str, Enum):
    r"""The style to generate images with. When photoReal is enabled, refer to the Guide section for a full list. When alchemy is disabled, use LEONARDO or NONE. When alchemy is enabled, use ANIME, CREATIVE, DYNAMIC, ENVIRONMENT, GENERAL, ILLUSTRATION, PHOTOGRAPHY, RAYTRACED, RENDER_3D, SKETCH_BW, SKETCH_COLOR, or NONE."""
    ANIME = 'ANIME'
    BOKEH = 'BOKEH'
    CINEMATIC = 'CINEMATIC'
    CINEMATIC_CLOSEUP = 'CINEMATIC_CLOSEUP'
    CREATIVE = 'CREATIVE'
    DYNAMIC = 'DYNAMIC'
    ENVIRONMENT = 'ENVIRONMENT'
    FASHION = 'FASHION'
    FILM = 'FILM'
    FOOD = 'FOOD'
    GENERAL = 'GENERAL'
    HDR = 'HDR'
    ILLUSTRATION = 'ILLUSTRATION'
    LEONARDO = 'LEONARDO'
    LONG_EXPOSURE = 'LONG_EXPOSURE'
    MACRO = 'MACRO'
    MINIMALISTIC = 'MINIMALISTIC'
    MONOCHROME = 'MONOCHROME'
    MOODY = 'MOODY'
    NONE = 'NONE'
    NEUTRAL = 'NEUTRAL'
    PHOTOGRAPHY = 'PHOTOGRAPHY'
    PORTRAIT = 'PORTRAIT'
    RAYTRACED = 'RAYTRACED'
    RENDER_3_D = 'RENDER_3D'
    RETRO = 'RETRO'
    SKETCH_BW = 'SKETCH_BW'
    SKETCH_COLOR = 'SKETCH_COLOR'
    STOCK_PHOTO = 'STOCK_PHOTO'
    VIBRANT = 'VIBRANT'
    UNPROCESSED = 'UNPROCESSED'
